@@ -74,6 +74,8 @@ pub const EMPTY_SPACE: &'static str = " ";
 /// Byte representation of `AUTH`.
 pub const AUTH: &'static str = "AUTH";
 
+pub use crate::utils::{PATTERN_PUBSUB_PREFIX, PUBSUB_PREFIX, PUBSUB_PUSH_PREFIX};
+
 /// A map struct for frames.
 #[cfg(not(feature = "index-map"))]
 pub type FrameMap = HashMap<Frame, Frame>;
@@ -969,6 +971,14 @@ impl Frame {
     }
   }
 
+  /// Whether or not the frame is a `Null` variant.
+  pub fn is_null(&self) -> bool {
+    match *self {
+      Frame::Null => true,
+      _ => false,
+    }
+  }
+
   /// Whether or not the frame represents an array of frames.
   pub fn is_array(&self) -> bool {
     match *self {
